Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(686)

Unified Diff: webrtc/modules/audio_device/linux/audio_device_pulse_linux.h

Issue 1722083002: Replace scoped_ptr with unique_ptr in webrtc/modules/audio_device/ (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/modules/audio_device/linux/audio_device_pulse_linux.h
diff --git a/webrtc/modules/audio_device/linux/audio_device_pulse_linux.h b/webrtc/modules/audio_device/linux/audio_device_pulse_linux.h
index de8df0be1bae369b5ccf4cfd638da4c185230d95..a0a15e5f0e7122fdd12686ec230c3b61b294da6c 100644
--- a/webrtc/modules/audio_device/linux/audio_device_pulse_linux.h
+++ b/webrtc/modules/audio_device/linux/audio_device_pulse_linux.h
@@ -11,6 +11,8 @@
#ifndef WEBRTC_AUDIO_DEVICE_AUDIO_DEVICE_PULSE_LINUX_H
#define WEBRTC_AUDIO_DEVICE_AUDIO_DEVICE_PULSE_LINUX_H
+#include <memory>
+
#include "webrtc/base/platform_thread.h"
#include "webrtc/base/thread_checker.h"
#include "webrtc/modules/audio_device/audio_device_generic.h"
@@ -284,9 +286,9 @@ private:
EventWrapper& _recStartEvent;
EventWrapper& _playStartEvent;
- // TODO(pbos): Remove scoped_ptr and use directly without resetting.
- rtc::scoped_ptr<rtc::PlatformThread> _ptrThreadPlay;
- rtc::scoped_ptr<rtc::PlatformThread> _ptrThreadRec;
+ // TODO(pbos): Remove unique_ptr and use directly without resetting.
+ std::unique_ptr<rtc::PlatformThread> _ptrThreadPlay;
+ std::unique_ptr<rtc::PlatformThread> _ptrThreadRec;
int32_t _id;
AudioMixerManagerLinuxPulse _mixerManager;
« no previous file with comments | « webrtc/modules/audio_device/linux/audio_device_alsa_linux.h ('k') | webrtc/modules/audio_device/mac/audio_device_mac.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698